package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.EmissionFactor;

import java.util.List;

/**
 * 排放因子Service接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface IEmissionFactorService {
    /**
     * 查询排放因子
     *
     * @param id 排放因子维主
     * @return 排放因子
     */
    EmissionFactor selectEmissionFactorById(Long id);

    /**
     * 根据区域编码和因子类型查询排放因子
     * @param regionCode 区域编码
     * @param factorType 因子类型
     * @return 排放因子
     */
    EmissionFactor selectByRegion(String regionCode, int factorType);

    /**
     * 查询排放因子列表
     *
     * @param emissionFactor 排放因子
     * @return 排放因子集合
     */
    List<EmissionFactor> selectEmissionFactorList(EmissionFactor emissionFactor);

    /**
     * 新增排放因子
     *
     * @param emissionFactor 排放因子
     * @return 结果
     */
    int insertEmissionFactor(EmissionFactor emissionFactor);

    /**
     * 修改排放因子
     *
     * @param emissionFactor 排放因子
     * @return 结果
     */
    int updateEmissionFactor(EmissionFactor emissionFactor);

    /**
     * 批量删除排放因子
     *
     * @param ids 需要删除的排放因子主键集合
     * @return 结果
     */
    int deleteEmissionFactorByIds(Long[] ids);

    /**
     * 删除排放因子信息
     *
     * @param id 排放因子主键
     * @return 结果
     */
    int deleteEmissionFactorById(Long id);
}
